==> letsnet-normapi-1.3.0.tgz: package/queue.js <==
var Ajv = require('ajv')
var ajv = new Ajv({allErrors: true})

var Queue = function(object) {
    this.counter = 1
    this.masterFunction = null
    if(object[0] instanceof Function) {
        this.queue = Object.entries(object)
        this.sharedObject = {}
    } else {
        this.queue = Object.entries(object)
        this.sharedObject = this.queue.shift()[1] || {}
    }
    this.queueLength = this.queue.length
}

Queue.prototype.next = function() {
    if(this.queueLength == this.counter) {
        var callback = this.queue.shift()[1]
        this.masterFunction(this.sharedObject)
        .then(function(response) {
            if(process.env.DEVELOPERCONSOLE == 'true' && process.env.QUEUE_THEN_LOGS == 'true') console.developer.log(response)
            callback(false, {func: response.func || 'anonymus', lCode: response.lCode || '-S', msg: response.msg || 'Sikeres lefutás!', type: response.type || 'success', document: response.document || null})
        })
        .catch(function(response) {
            console.log(response)
            if(process.env.DEVELOPERCONSOLE == 'true' && process.env.QUEUE_CATCH_LOGS == 'true') console.developer.log(response)
            callback(true, {func: response.func || 'anonymus', lCode: response.lCode || '-E', msg: response.msg || 'Sikertelen lefutás!', type: response.type || 'error'})
        })
    }
    else {
        ++this.counter
        return this.queue.shift()[1](this.sharedObject, this)
    }
}

Queue.prototype.stop = function(object) {
    var callback = this.queue.pop()[1]
    this.queue = null
    callback(true, {func: object.func || 'anonymus', lCode: object.lCode || '-E2', msg: object.msg || 'Sikertelen lefutás!', type: object.type || 'queue-error'})
}

Queue.prototype.setMasterFunction = function(schema, masterFunction) {
    if(schema === undefined || schema == null) this.masterFunction = masterFunction
    else this.masterFunction = function(object) {
        return new Promise(function(resolve, reject) {
            var valid = ajv.validate(schema, object)
            if(valid) {
                masterFunction(object).then(function(response) {
                    resolve(response)
                }).catch(function(response) {
                    console.log(ajv.errors)
                    reject(response)
                })
            }
            else reject({func: '@dataChecker', lCode: '-DC', msg: 'Hibás adatokat adott meg!', type: 'data-error'})
        })
    }
}

module.exports = Queue

==> letsnet-normapi-1.3.6.tgz: package/queue.js <==
var Ajv = require('ajv')
var ajv = new Ajv({allErrors: true})

var Queue = function(object) {
    this.counter = 1
    this.masterFunction = null
    if(object[0] instanceof Function) {
        this.queue = Object.entries(object)
        this.sharedObject = {}
    } else {
        this.queue = Object.entries(object)
        this.sharedObject = this.queue.shift()[1] || {}
    }
    this.queueLength = this.queue.length
}

Queue.prototype.next = function() {
    if(this.queueLength == this.counter) {
        var callback = this.queue.shift()[1]
        this.masterFunction(this.sharedObject)
        .then(function(response) {
            /*IFLOG*/if(process.env.QUEUE_THEN_RESPONSE == 'true') console.developer.log(response)
            callback(false, {func: response.func || 'anonymus', lCode: response.lCode || '-S', msg: response.msg || 'Sikeres lefutás!', type: response.type || 'success', document: response.document || null})
        })
        .catch(function(response) {
            /*IFLOG*/if(process.env.QUEUE_CATCH_RESPONSE == 'true') console.developer.log(response)
            callback(true, {func: response.func || 'anonymus', lCode: response.lCode || '-E', msg: response.msg || 'Sikertelen lefutás!', type: response.type || 'error'})
        })
    }
    else {
        ++this.counter
        return this.queue.shift()[1](this.sharedObject, this)
    }
}

Queue.prototype.stop = function(object) {
    var callback = this.queue.pop()[1]
    this.queue = null
    /*IFLOG*/if(process.env.QUEUE_STOP_LOG == 'true') console.developer.log(object)
    callback(true, {func: object.func || 'anonymus', lCode: object.lCode || '-E2', msg: object.msg || 'Sikertelen lefutás!', type: object.type || 'queue-error'})
}

Queue.prototype.setMasterFunction = function(schema, masterFunction) {
    if(schema === undefined || schema == null) this.masterFunction = masterFunction
    else this.masterFunction = function(object) {
        return new Promise(function(resolve, reject) {
            var valid = ajv.validate(schema, object)
            /*IFLOG*/if(process.env.AJV_ERROR_LOG == 'true') console.developer.log(ajv.errors)
            if(valid) {
                masterFunction(object).then(function(response) {
                    resolve(response)
                }).catch(function(response) {
                    reject(response)
                })
            }
            else reject({func: '@dataChecker', lCode: '-DC', msg: 'Hibás adatokat adott meg!', type: 'data-error'})
        })
    }
}

module.exports = Queue
